# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][],
and this project adheres to [Semantic Versioning][].

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

## 0.1.0 (2023-03-19)

### Added

-   Scanpy lower bound
-   Cookiecutter template update

### Fixed

-   Docs

## 0.0.1 (2023-01-30)

### Added

-   Initial API
